==> e107-0.7.20.tbz: www/e107/e107_languages/English/lan_news.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $Source: /cvs_backup/e107_0.7/e107_languages/English/lan_news.php,v $
|     $Revision: 11465 $
|     $Date: 2010-04-07 16:36:23 -0400 (Wed, 07 Apr 2010) $
|     $Author: e107steved $
+----------------------------------------------------------------------------+
*/
define("PAGE_NAME", "News");


define("LAN_NEWS_1", "News for specific members only");
define("LAN_NEWS_2", "You are not allowed to see this news");
define("LAN_NEWS_9", "Title only is set - <b>only the news title will be shown</b><br />");
define("LAN_NEWS_10", "This news post is <b>inactive</b> (It will be not shown on front page). ");
define("LAN_NEWS_11", "This news post is <b>active</b> (it will be shown on front page). ");
define("LAN_NEWS_12", "Comments are turned <b>on</b>. ");
define("LAN_NEWS_13", "Comments are turned <b>off</b>. ");
define("LAN_NEWS_14", "<br />Activation period: ");
define("LAN_NEWS_15", "Body length: ");
define("LAN_NEWS_16", "b. Extended length: ");
define("LAN_NEWS_17", "b.");
define("LAN_NEWS_18", "Info:");
define("LAN_NEWS_19", "Now");
define("LAN_NEWS_23", "News Categories");
define("LAN_NEWS_24", "create pdf of this news item");
define("LAN_NEWS_25", "Edit");
define('LAN_NEWS_31', 'Sticky news item');					// Added
define('LAN_NEWS_82', 'News - Category');
define('LAN_NEWS_83', 'No news items at the moment - please check back soon.');
define('LAN_NEWS_84', 'Back to news overview');
define('LAN_NEWS_85', 'Back to category overview');
define('LAN_NEWS_86', 'Older News');
define('LAN_NEWS_87', 'Newer News');
define("LAN_NEWS_462", "No news items for specified month");

// Following used by alt_news
define("LAN_99", 'Comments');
define("LAN_100", 'On');
define("LAN_307", 'Total posts in this category: ');

?>

==> e107-1.0.3.tbz: www/e107/e107_languages/English/lan_news.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_languages/English/lan_news.php $
|     $Revision: 11678 $
|     $Id: lan_news.php 11678 2010-08-22 00:43:45Z e107coders $
|     $Author: e107coders $
+----------------------------------------------------------------------------+
*/
define("PAGE_NAME", "News");


define("LAN_NEWS_1", "News for specific members only");
define("LAN_NEWS_2", "You are not allowed to see this news");
define("LAN_NEWS_9", "Title only is set - <b>only the news title will be shown</b><br />");
define("LAN_NEWS_10", "This news post is <b>inactive</b> (It will be not shown on front page). ");
define("LAN_NEWS_11", "This news post is <b>active</b> (it will be shown on front page). ");
define("LAN_NEWS_12", "Comments are turned <b>on</b>. ");
define("LAN_NEWS_13", "Comments are turned <b>off</b>. ");
define("LAN_NEWS_14", "<br />Activation period: ");
define("LAN_NEWS_15", "Body length: ");
define("LAN_NEWS_16", "b. Extended length: ");
define("LAN_NEWS_17", "b.");
define("LAN_NEWS_18", "Info:");
define("LAN_NEWS_19", "Now");
define("LAN_NEWS_23", "News Categories");
define("LAN_NEWS_24", "create pdf of this news item");
define("LAN_NEWS_25", "Edit");
define('LAN_NEWS_31', 'Sticky news item');					// Added
define('LAN_NEWS_82', 'News - Category');
define('LAN_NEWS_83', 'No news items at the moment - please check back soon.');
define('LAN_NEWS_84', 'Back to news overview');
define('LAN_NEWS_85', 'Back to category overview');
define('LAN_NEWS_86', 'Older News');
define('LAN_NEWS_87', 'Newer News');
define("LAN_NEWS_462", "No news items for specified month");

// Following used by alt_news
define('LAN_NEWS_99', 'Comments');
define('LAN_NEWS_100', 'On');
define('LAN_NEWS_307', 'Total posts in this category: ');

?>
